@@ -105,7 +105,6 @@ _vte_pty_reset_signal_handlers(void)
 	signal(SIGHUP,  SIG_DFL);
 #endif
 	signal(SIGINT,  SIG_DFL);
-	signal(SIGQUIT, SIG_DFL);
 	signal(SIGILL,  SIG_DFL);
 	signal(SIGABRT, SIG_DFL);
 	signal(SIGFPE,  SIG_DFL);
@@ -1668,7 +1667,7 @@ vte_pty_error_quark(void)
  * vte_pty_child_setup() directly as the child setup function, or call
  * vte_pty_child_setup() from your own child setup function supplied.
  *
- * When using vte_terminal_fork_command_full() with a custom child setup
+ * When using vte_terminal_spawn_sync() with a custom child setup
  * function, vte_pty_child_setup() will be called before the supplied
  * function; you must not call it again.
  *
